#/bin/bash

# mapWOC
#
# Description: Helper to setup an environment to run mapwoc in.
#
# Copyright:
# Copyright (C) 2012 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.# GPL

# Fail if a command fails.
set -e

USER=`whoami`

# TODO In future, exit if not user mapwoc.
[ -n "$USER" -a "$USER" = "mapwoc" ] || { echo "Not user mapwoc (but $USER)." ; exit 2 ; }

# Create ~/.ssh directory.
SSHDIR=/home/"$USER"/.ssh
echo "Creating ~/.ssh"
mkdir -m 700 -p "$SSHDIR"

# Create ssh key and place in /var/lib/mapwoc/master/key/ , allow access.
echo "Creating master credentials"
KEYDIR=/var/lib/mapwoc/master/credentials/
KEYFILE="$KEYDIR/master_key"
if [ ! -e "$KEYFILE" ]; then
  ssh-keygen -N "" -q -f "$KEYFILE" 

  # For the node, allow checks from master.
  echo "Allow SSH access from master."
  cat "$KEYFILE".pub >> "$SSHDIR/authorized_keys"

  # For the master, trust yourself (avoid questions about fingerprint).
  touch "$SSHDIR"/known_hosts
  echo -n "localhost ssh-rsa " >> "$SSHDIR"/known_hosts
  ssh-keygen -e  -f /etc/ssh/ssh_host_rsa_key | tail -n+3 | head -n-1 | awk '{printf "%s", $0}' >> "$SSHDIR"/known_hosts
fi

NODECONFFILE=/var/lib/mapwoc/master/nodes/localnode.config
if [ ! -e "$NODECONFFILE" ]; then
  # Register node information for master
  echo "Creating a node configuration file."
  [ ! -e "$NODECONFFILE" ] || { echo "Node configuration file in $NODECONFFILE exists already" ; exit 4 ; }
  touch "$NODECONFFILE"
  echo "[localnode]" >> "$NODECONFFILE"
  echo "name=Local Node" >> "$NODECONFFILE"
  echo "description=This node runs on the same host as the master" >> "$NODECONFFILE"
  echo "rsync_address=localhost" >> "$NODECONFFILE"
  echo "ip=localhost" >> "$NODECONFFILE"
  echo "port=18158" >> "$NODECONFFILE"
fi

# TODO Setup Web GUI better
echo "Setting up WEB GUI"
if [ ! -e /home/"$USER"/mapwoc-gui ]; then
  mkdir -p /home/"$USER"/mapwoc-gui
  cd /home/"$USER"/mapwoc-gui
  paster make-config "mapwocgui" mapwoc-gui.ini

  # Create a user with this password ...
  CHAR="[:alnum:]"
  PASS=`cat /dev/urandom | tr -cd $CHAR | head -c 8`

  echo $PASS > /home/"$USER"/mapwoc-gui/mapwocgui-admin-password

  paster setup-app mapwoc-gui.ini < /dev/null
  /usr/lib/mapwoc/mapwocgui-adduser.py /home/"$USER"/mapwoc-gui/mapwoc-gui.ini admin "$PASS"

  echo "Find initial admin password in /home/mapwoc/mapwoc-gui/mapwocgui-admin-password."
  echo "You can start the gui with 'paster serve mapwoc-gui.ini' ."
fi

# Install default mitmproxy certs
mkdir -p /home/"$USER"/.mitmproxy
cp -r /etc/mapwoc/mitmproxy/* /home/"$USER"/.mitmproxy

true
